'apt install my-sql-server ' ei kopio tarvittavia tiedostoja kiintolevylle.
dpkg: warning: files list file for package 'apache2-utils' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'apache2-bin' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'apache2-data' missing; assuming package has no files currently installed
Kuitenkin nuo on asennettu ja poistettu ja asennettu uudestaan.. koittanut 'apt purge my-sql-server' ym.. ei auta.
Joutuuko tässä asentamaan koko käyttöjärjestelmän uudestaan?
dpkg: warning: files list file for package 'apache2-utils' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'apache2-bin' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'apache2-data' missing; assuming package has no files currently installed
Kuitenkin nuo on asennettu ja poistettu ja asennettu uudestaan.. koittanut 'apt purge my-sql-server' ym.. ei auta.
Joutuuko tässä asentamaan koko käyttöjärjestelmän uudestaan?
Vastaukset 11
Vanhimmat
sudo apt-get -f install
apt install mysql-server ?
Poistoon moinen käyttis!
Vaihda Windowsiin!!!
HV, ja poista itsesi täältä virusimuria mainostamasta!
sudo apt-get -f install ja apt install mysql-server on luonnollisesti ensimmäiset mitä kokeilen. Mutta kun se ei asenna tarvittavia tiedostoja koneeseen vaikka asennus näyttää menevän normaalisti läpi.
Onko kyseiset paketit pakettivarastossa?
Tässä LMDE2:ssa ne ovat samoin kuin tuo mysql-server.
Kyllä ne sieltä löytyy. Poistin käsin conffi tiedostoja etc sekä usr hakemistosta kun asennus ei onnistunut ja oletin että tottakai asennuksen aikana kaikki kopioidaan uudestaan sinne. No eipä kopioinut ja nyt on mysql rikki.
Kaikki dpkg pakettihallinan virheet pitää korjata niin että se virheellisesti poistettu tai asennettu paketti saatetaan ajantasalle näin:
sudo dpkg --remove --force-remove-reinstreq <virheellinen paketti>
Sinun antamasi viesti, edellyttää näiden rivien suorittamista:
sudo dpkg --remove --force-remove-reinstreq apache2-utils
sudo dpkg --remove --force-remove-reinstreq apache2-bin
sudo dpkg --remove --force-remove-reinstreq apache2-data
Jos et tee noita korjauksia, voi olla että jatkossa pakettilähteiden päivitys pysähtyy aina virheeseen.
Jotain
https://serverfault.com/questions/430682/dpkg-warning-files-list-file-for-package-x-missing
Juuri näin, pakettilähde tietää mitä se itse on tehnyt asennuksen aikana. Jos se havaitsee epäkohdan - eli jokin tiedosto on eri lailla/puuttuu - se varoitta tästä jos käsketyn homman pystyy kuitenkin tekemään. Ja jos ei pysty niin sitten oletetaan, että ohjelma on asennettu jotain muuta reittiä ja lyödään kädet pystyyn ettei aiheuteta pahempia tuhoja.
Sen kuitenkin tietää itse, jos vaikka virrat menny kesken paketin asennuksen että tulee pakettilähteestä ja voimaa käyttämällä asian saa kuntoon. Itse olen tapellut virtualbox:n kansa ja sen kerneli-modulin kääntäävn paketin kanssa aikanaan pitkään tästä systä kun käännös oli tehty eri hakemistossa kuin paketinhallinta luuli - eli sääntöjen vastaisesti.
Myös "apt install -reinstall paketti" riittää joskus. Ja lock-tiedoston poistoon voi joutua kanssa turvautuman, jos esim. sulkee konetta huolimattomasti, mutta senhän em. ohjelma osaa kertoa.
Onnistuin nyt!
Piti poistaa kaikki nimeen viittaavat eli 'sudo apt purge apache2*'
Poistin sql:n myös * -merkillä varustettuna, ja javascript-common piti myös poistaa, jotta pääsin seuraavasta ongelma eteenpäin.